pub struct StreamingGraphRelationLoader { /* private fields */ }Expand description
Streaming loader for typed biomedical graph relation rows.
Implementations
Sourceimpl StreamingGraphRelationLoader
impl StreamingGraphRelationLoader
Sourcepub fn new(format: GraphInputFormat) -> Self
pub fn new(format: GraphInputFormat) -> Self
Create a loader for the given input format.
Sourcepub fn with_chunk_rows(self, chunk_rows: usize) -> Self
pub fn with_chunk_rows(self, chunk_rows: usize) -> Self
Set the maximum number of rows accounted to a single streaming chunk.
Sourcepub fn load_path(
&self,
path: impl AsRef<Path>,
) -> Result<GraphRelationLoadReport>
pub fn load_path( &self, path: impl AsRef<Path>, ) -> Result<GraphRelationLoadReport>
Stream a graph file and return provenance and histogram telemetry.
Sourcepub fn load_path_with_sink(
&self,
path: impl AsRef<Path>,
sink: impl FnMut(GraphEdgeRow),
) -> Result<GraphRelationLoadReport>
pub fn load_path_with_sink( &self, path: impl AsRef<Path>, sink: impl FnMut(GraphEdgeRow), ) -> Result<GraphRelationLoadReport>
Stream a graph file into a caller-provided edge sink and return telemetry.