pub enum RelationDeltaDirection {
Insert,
Delete,
}Expand description
Direction of an incoming relation-delta occurrence.
Variants
Insert
Tuples supplied on the insertion side of an update.
Delete
Tuples supplied on the deletion side of an update.