pub struct LogicArgumentSchema { /* private fields */ }Expand description
Read-only metadata for one argument of a compiled relation.
Implementations
Sourceimpl LogicArgumentSchema
impl LogicArgumentSchema
Sourcepub fn source_named(&self) -> bool
pub fn source_named(&self) -> bool
Return whether the column name was written in the source declaration.
Sourcepub fn scalar_type(&self) -> ScalarType
pub fn scalar_type(&self) -> ScalarType
Return the resolved scalar type from the compiled relation schema.